#
# In contrast to the paradigm of isolated tests, this spec uses Celsius::Primo
# indirectly. The idea is, that these two adapter work very closely with each
# other and always updating the stubbed responses from Celsius::Primo in here
# does not seem be appropriate.
#
describe Celsius::PrimoUbpb::Adapter do
  let(:adapter_options) do
    {
      institution: "PAD",
      languages: [
        "ger",
        "eng"
      ],
      locations:[
        {
          type: "local",
          value: "scope:(PAD_ALEPH)"
        }
      ],
      soap_api_options: {
        searcher_url: "http://primo.kobv.de/primo_library/libweb/webservices/services/searcher"
      }
    }
  end

  let(:adapter) do
    described_class.new(adapter_options)
  end

  describe "#search" do
    asset_dir = "adapter/search"

    it "returns a ubpb extended search result", :vcr do
      [
        ["#{asset_dir}/search_request.yml", "#{asset_dir}/search_result.yml"],
        ["#{asset_dir}/search_request_with_empty_result.yml", "#{asset_dir}/empty_search_result.yml"]
      ]
      .each do |search_request_yaml_filename, search_response_yaml_filename|
        search_request = YAML.load(read_asset(search_request_yaml_filename))
        expected_search_result = YAML.load(read_asset(search_response_yaml_filename))

        expect(search_result = adapter.search(search_request)).to eq(expected_search_result)
      end
    end
  end
end
